<?php
/**
 * $Horde: hermes/lib/Search.php,v 1.13 2005/01/03 14:34:55 jan Exp $
 *
 * Copyright 2004-2005 Jay 'Eraserhead' Felice <jfelice@cronosys.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */
class SearchForm extends Horde_Form {
    
    function SearchForm(&$vars)
    {
        parent::Horde_Form($vars, _("Search For Time"));

        if ($GLOBALS['perms']->hasPermission('hermes:review', Auth::getAuth(), PERMS_SHOW)) {
            $type = Hermes::getEmployeesType();
            $this->addVariable(_("Employees"), 'employees', $type[0], false,
                               false, null, $type[1]);
        }

        $type = $this->getClientsType();
        $this->addVariable(_("Clients"), 'clients', $type[0], false, false,
                           null, $type[1]);

        $type = $this->getJobTypesType();
        $this->addVariable(_("Job Types"), 'jobtypes', $type[0], false, false,
                           null, $type[1]);

        $this->addVariable(_("Do not include entries before"), 'start',
                           'monthdayyear', false);
        $this->addVariable(_("Do not include entries after"), 'end',
                           'monthdayyear', false);

        $states = array(''      => "",
                        '1'     => _("Yes"),
                        '0'     => _("No"));
        $this->addVariable(_("Submitted?"), 'submitted', 'enum', false, false,
                           null, array($states));

        $this->addVariable(_("Exported?"), 'exported', 'enum', false, false,
                           null, array($states));
    }

    function getClientsType()
    {
        $clients = Hermes::listClients();
        if (is_a($clients, 'PEAR_Error')) {
            return array('invalid', array(sprintf(_("An error occurred listing clients: %s"),
                                           $clients->getMessage())));
        } else {
            return array('multienum', array($clients));
        }
    }

    function getJobTypesType()
    {
        global $hermes;

        $types = $hermes->getJobTypes();
        if (is_a($types, 'PEAR_Error')) {
            return array('invalid', array(sprintf(_("An error occurred listing job types: %s"),
                                           $types->getMessage())));
        } else {
            return array('multienum', array($types));
        }
    }

    function getSearchCriteria(&$vars)
    {
        if (!$this->isValid()) {
            return null;
        }
        $this->getInfo($vars, $info);

        $criteria = array();
        if ($GLOBALS['perms']->hasPermission('hermes:review', Auth::getAuth(), PERMS_SHOW)) {
            if (!empty($info['employees'])) {
                $auth = &Auth::singleton($GLOBALS['conf']['auth']['driver']);
                if (!$auth->capabilities['list']) {
                    $criteria['employee'] = split(',', $info['employees']);
                } else {
                    $criteria['employee'] = $info['employees'];
                }
            }
        } else {
            $criteria['employee'] = Auth::getAuth();
        }
        if (!empty($info['clients'])) {
            $criteria['client'] = $info['clients'];
        }
        if (!empty($info['jobtypes'])) {
            $criteria['jobtype'] = $info['jobtypes'];
        }
        if (!empty($info['start'])) {
            $dt = &new Date($info['start']);
            $criteria['start'] = $dt->getDate(DATE_FORMAT_UNIXTIME);
        }
        if (!empty($info['end'])) {
            $dt = &new Date($info['end']);
            $dt->setHour(23);
            $dt->setMinute(59);
            $dt->setSecond(59);
            $criteria['end'] = $dt->getDate(DATE_FORMAT_UNIXTIME);
        }
        if (isset($info['submitted']) && $info['submitted'] != '') {
            $criteria['submitted'] = $info['submitted'];
        }
        if (isset($info['exported']) && $info['exported'] != '') {
            $criteria['exported'] = $info['exported'];
        }
        return $criteria;
    }

}

/**
 * ExportForm:: is the export form which appears with search results on
 * the search screen.
 *
 * @author  Jason M. Felice <jfelice@cronosys.com>
 * @version $Revision: 1.13 $
 * @package Hermes
 */
class ExportForm extends Horde_Form {

    function ExportForm(&$vars)
    {
        global $perms;
        parent::Horde_Form($vars, _("Export Search Results"));

        $formats = array('csv' => _("Comma-Separated Variable (.csv)"),
                         'tsv' => _("Tab-Separated Variable (.tsv,.txt)"),
                         'iif' => _("QuickBooks (.iif)"));

        $this->addVariable(_("Select the export format"), 'format', 'enum',
                           true, false, null, array($formats));

        if ($perms->hasPermission('hermes:review', Auth::getAuth(),
                                  PERMS_EDIT)) {
            $yesno = array('yes' => _("Yes"),
                           'no' => _("No"));
            $var = &$this->addVariable(_("Mark the time as exported?"),
                                       'mark_exported', 'enum', true, false,
                                       null, array($yesno)); 
            $var->setDefault('no');
        }
    }

}
