<?php
/**
 * Hermes external API interface.
 *
 * $Horde: hermes/lib/api.php,v 1.18 2004/12/23 17:51:58 jan Exp $
 *
 * This file defines Hermes's external API interface. Other applications
 * can interact with Hermes through this API.
 *
 * @package Hermes
 */

$_services['perms'] = array(
    'args' => array(),
    'type' => 'stringArray');

$_services['getTableMetaData'] = array(
    'args' => array('name', 'params'),
    'type' => 'stringArray');

$_services['getTableData'] = array(
    'args' => array('name', 'params', 'start', 'end'),
    'type' => 'stringArray');

function _hermes_perms()
{
    $perms = array();
    $perms['tree']['hermes']['review'] = array();
    $perms['title']['hermes:review'] = _("Time Review Screen");

    return $perms;
}

function _hermes_getTableMetaData($name, $params)
{
    @define('HERMES_BASE', dirname(__FILE__) . '/..');
    require_once HERMES_BASE . '/lib/base.php';
    global $conf, $hermes;

    switch ($name) {
    case 'hours':
        $emptype = Hermes::getEmployeesType('enum');
        $clients = Hermes::listClients();
        $hours = $hermes->getHours($params);
        $yesno = array(1 => _("Yes"),
                       0 => _("No"));

        $columns = array(
            array('name'    => 'icons',
                  'title'   => '*',
                  'type'    => '%html',
                  'nobr'    => true),
            array('name'    => 'checkbox',
                  'title'   => '',
                  'type'    => '%html',
                  'nobr'    => true),
            array('name'    => 'date',
                  'title'   => _("Date"),
                  'type'    => 'date',
                  'params'  => array($GLOBALS['prefs']->getValue('date_format')),
                  'nobr'    => true),
            array('name'    => 'employee',
                  'title'   => _("Employee"),
                  'type'    => $emptype[0],
                  'params'  => $emptype[1]),
            array('name'    => 'client',
                  'title'   => _("Client"),
                  'type'    => 'enum',
                  'params'  => array($clients)),
            array('name'    => '_type_name',
                  'title'   => _("Job Type")),
            array('name'    => 'hours',
                  'title'   => _("Hours"),
                  'type'    => 'number',
                  'align'   => 'right'));
        if ($conf['time']['choose_ifbillable']) {
            $columns[] =
                array('name'    => 'billable',
                      'title'   => _("Bill?"),
                      'type'    => 'enum',
                      'params'  => array($yesno));
        }
        $columns = array_merge($columns, array(
            array('name'    => 'description',
                  'title'   => _("Description")),
            array('name'    => 'note',
                  'title'   => _("Additional Notes"))));

        $fColumns = array(
            array('name'    => 'blank1',
                  'colspan' => 6),
            array('name'    => 'hours',
                  'type'    => 'number',
                  'align'   => 'right'));
        if ($conf['time']['choose_ifbillable']) {
            $fColumns[] =
                array('name'    => 'billable',
                      'type'    => 'enum',
                      'params'  => array($yesno));
        }
        $fColumns = array_merge($fColumns, array(
            array('name'    => 'description'),
            array('name'    => 'blank2')));

        return array('title' => _("Search Results"),
                     'sections' => array(
                         'data' => array(
                             'rows' => count($hours),
                             'columns' => $columns),
                         'footer' => array(
                             'rows' => 3,
                             'strong' => true,
                             'columns' => $fColumns)));

    default:
        return PEAR::raiseError(sprintf(_("'%s' is not a defined table."),
                                        $name));
    }
}

function _hermes_getTableData($name, $params, $range)
{
    @define('HERMES_BASE', dirname(__FILE__) . '/..');
    require_once HERMES_BASE . '/lib/base.php';

    global $hermes, $registry;

    switch ($name) {
    case 'hours':
        $result['data'] = $hermes->getHours($params);
		if (is_a($result['data'], 'PEAR_Error')) {
			return $result['data'];
		}

        $total_hours = 0.0;
        $total_billable_hours = 0.0;

        // From the search screen, we handle search and edit there so
        // that we end up on the search screen. This is how we know
        // where to make the links.
        $link_page = isset($params['link_page']) ? $params['link_page'] : 'time.php';

        foreach ($result['data'] as $k => $vals) {
            // Set up edit/delete icons.
            if (Hermes::canEditTimeslice($vals['id'])) {
                $edit_link = Horde::applicationUrl('entry.php', true);
                $edit_link = Util::addParameter($edit_link, 'id', $vals['id']);

                $delete_link = Horde::applicationUrl($link_page, true);
                $delete_link = Util::addParameter($delete_link, 'delete', $vals['id']);

                $result['data'][$k]['icons'] =
                    Horde::link($edit_link, _("Edit Entry")) .
                    Horde::img('edit.png', _("Edit Entry"), '', $registry->getImageDir('horde')) . '</a>' .
                    Horde::link($delete_link, _("Delete Entry")) .
                    Horde::img('delete.png', _("Delete Entry"), '', $registry->getImageDir('horde')) .
                    '</a>';

                if (empty($vals['submitted'])) {
                    $result['data'][$k]['checkbox'] =
                        '<input type="checkbox" name="item[' .
                        htmlspecialchars($vals['id']) .
                        ']" checked="checked" />';
                } else {
                    $result['data'][$k]['checkbox'] = '';
                }
            }

            // Add to totals.
            $total_hours += (double)$vals['hours'];
            if ($vals['billable']) {
                $total_billable_hours += (double)$vals['hours'];
            }
        }

        // Avoid a divide by zero.
        if ($total_hours == 0.0) {
            $billable_pct = 0.0;
        } else {
            $billable_pct = round($total_billable_hours / $total_hours * 100.0);
        }

        $descr = _("Billable Hours") . ' (' . $billable_pct . '%)';
        $result['footer'] = array();
        $result['footer'][] = array('hours'       => sprintf('%.02f', $total_billable_hours),
                                    'description' => $descr);

        $descr = _("Non-billable Hours") . ' (' . (100.0 - $billable_pct) . '%)';
        $result['footer'][] = array('hours'       => sprintf('%.02f', $total_hours - $total_billable_hours),
                                    'description' => $descr);
        $result['footer'][] = array('hours'       => sprintf('%.02f', $total_hours),
                                    'description' => _("Total Hours"));
        break;
    }

    return $result;
}
