<?php
/**
 * $Horde: hermes/search.php,v 1.22 2005/01/03 14:34:55 jan Exp $
 *
 * Copyright 2004-2005 Jay 'Eraserhead' Felice <jfelice@cronosys.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('HERMES_BASE', dirname(__FILE__));
require_once HERMES_BASE . '/lib/base.php';
require_once HERMES_BASE . '/lib/TimeForm.php';
require_once HERMES_BASE . '/lib/Search.php';
require_once 'Horde/Identity.php';
require_once 'Horde/Data.php';
require_once 'Horde/Variables.php';
require_once 'Horde/UI/Table.php';

$vars = &Variables::getDefaultVariables();

$delete = $vars->get('delete');
if (!empty($delete)) {
    $result = $hermes->updateTime(array(array('id' => $delete, 'delete' => true)));
    if (is_a($result, 'PEAR_Error')) {
        Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("There was an error deleting the time: %s"), $result->getMessage()), 'horde.error');
    } else {
        $notification->push(_("The time entry was successfully deleted."), 'horde.success');
        $vars->remove('delete');
    }
}

$criteria = null;

$formname = $vars->get('formname');
switch ($formname) {
case 'timereviewform':
    $form = &Horde_Form::singleton('TimeReviewForm', $vars);
    $form->validate($vars);
    if ($form->isValid()) {
        $form->getInfo($vars, $info);
        $result = $hermes->updateTime(array($info));
        if (is_a($result, 'PEAR_Error')) {
            Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
            $notification->push(sprintf(_("There was an error storing your timesheet: %s"), $result->getMessage()), 'horde.error');
        } else {
            $notification->push(_("The timeslice was successfully updated."), 'horde.success');
            $vars = &new Variables();
        }
    }
    break;

case 'searchform':
    $form = &Horde_Form::singleton('SearchForm', $vars);
    $form->validate($vars);
    $criteria = $form->getSearchCriteria($vars);
    if (is_null($criteria)) {
        unset($_SESSION['hermes_search_criteria']);
    } else {
        $_SESSION['hermes_search_criteria'] = serialize($vars);
    }
    break;
}


$title = _("Search for Time");
require HERMES_TEMPLATES . '/common-header.inc';
require HERMES_TEMPLATES . '/menu.inc';

if ($vars->exists('id')) {
    // Editing a record.
    $id = $vars->get('id');
    $hours = $hermes->getHours(array('id' => $id));
    if (count($hours) != 1) {
        $notification->push(_("Could not retrieve timeslice: invalid id"),
                            'horde.error');
    } else {
        foreach ($hours[0] as $key => $value) {
            $vars->set($key, $value);
        }
    }

    $r = &new Horde_Form_Renderer();
    $form = &Horde_Form::singleton('TimeReviewForm', $vars);
    $form->renderActive($r, $vars, 'search.php', 'post');
} else {
    $r = &new Horde_Form_Renderer();
    if (isset($_SESSION['hermes_search_criteria'])) {
        $searchVars = unserialize($_SESSION['hermes_search_criteria']);
    } else {
        $searchVars = &$vars;
    }
    $form = &Horde_Form::singleton('SearchForm', $searchVars);
    $form->renderActive($r, $searchVars, 'search.php', 'post');
	echo '<br />';

    if (isset($_SESSION['hermes_search_criteria'])) {
        if (is_null($criteria)) {
            $criteria = $form->getSearchCriteria($searchVars);
        }

        $table = &new Horde_UI_Table('results', $vars,
                                     array('title' => _("Search Results"),
                                           'name' => 'hermes/hours',
                                           'params' => array_merge($criteria, array('link_page' => 'search.php'))));
        echo $table->render();
		echo '<br />';
    }
}

$exportForm = &Horde_Form::singleton('ExportForm', $vars);
$exportForm->renderActive($r, $vars, 'search.php', 'post');

require $registry->get('templates', 'horde') . '/common-footer.inc';
